djmicrosip_mail
==========================

Install or update
-------

### latest version ###
```
pip install --upgrade djmicrosip_mail
```
### An specific release version ###
```
pip install --upgrade djmicrosip_mail=[version]
```